{% extends "site_base.html" %} {% load pagination_tags %} {% load staticfiles %} {% load url from future %} {% load i18n %} {% block title %} {% trans "Announcements" %} - {{ block.super }} {% endblock %} {% block body_class %}maps{% endblock %} {% block body_outer %}
{% block body %}
{% trans "New Announcement" %}

## {% trans "Announcements" %}

{% trans "Title" %} | {% trans "Announcement" %} | {% trans "Published From" %}
{% for announcement in announcement_list %}
{{ announcement.title|truncatewords:50 }} | {{ announcement.content|truncatewords:8 }} | {% if announcement.publish_start or announcement.publish_end %} Published from {{ announcement.publish_start|date:"F j, Y" }} to {{ announcement.publish_end|date:"F j, Y"|default:"(no end date)" }}. {% endif %}
{% endfor %}

{% endblock %} {% endblock %}